.. _index:

fakepilot's |release|
=====================

``fakepilot`` |release| is a Python package for scrapping data from the `Trustpilot web page
<https://www.trustpilot.com/>`_.


Features
--------

* Extract the information of a company from a Trustpilot page.
* Obtain its reviews with a fine-grained detail.
* The output data is structured in a simple dictionary.

IMPORTANT: ``fakepilot`` now doesn't fetch the web pages from Trustpilot. This must be done by the user of the package.

Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   main-functionality
   api
   changelog
